slangpy.reflection
==================

The ``slangpy.reflection`` module is a wrapper around the Slang reflection API 
exposed by SGL. It is used extensively internally to SlangPy, but is a useful way 
of introspecting the Slang code in general. The most common way to access reflection 
data is by accessing the ``SlangProgramLayout`` of a module via the 
``Module.layout`` attribute.

API
---

.. automodule:: slangpy.reflection
   :members:
   :imported-members:
   